#!/bin/bash
set -euo pipefail

# Publish Docker image to GitHub Container Registry
# Usage: ./publish-docker.sh [tag] [username]

GITHUB_USERNAME="${2:-anosatsuk124}"
TAG="${1:-latest}"
LOCAL_IMAGE="voice-rss-summary:${TAG}"
GHCR_IMAGE_1="ghcr.io/${GITHUB_USERNAME}/voice-rss-summary:${TAG}"
GHCR_IMAGE_2="ghcr.io/${GITHUB_USERNAME}/voicersssummary:${TAG}"

echo "Publishing Docker image to GitHub Container Registry"
echo "Local image: ${LOCAL_IMAGE}"
echo "GHCR images: ${GHCR_IMAGE_1}, ${GHCR_IMAGE_2}"

# Check if local image exists
if ! docker image inspect "${LOCAL_IMAGE}" >/dev/null 2>&1; then
	echo "Error: Local Docker image '${LOCAL_IMAGE}' not found"
	echo "Build it first with: ./build-docker-image.sh ${TAG}"
	exit 1
fi

# Check if user is logged in to GHCR
if ! docker system info | grep -q "ghcr.io"; then
	echo "Checking GHCR authentication..."
	if ! echo "test" | docker login ghcr.io --username "${GITHUB_USERNAME}" --password-stdin >/dev/null 2>&1; then
		echo "Please authenticate with GitHub Container Registry first:"
		echo "1. Create a personal access token with 'write:packages' scope at:"
		echo "   https://github.com/settings/tokens"
		echo "2. Login with: echo \$GITHUB_TOKEN | docker login ghcr.io -u ${GITHUB_USERNAME} --password-stdin"
		echo "   or: docker login ghcr.io -u ${GITHUB_USERNAME}"
		exit 1
	fi
fi

# Tag images for GHCR
echo "Tagging images for GHCR..."
docker tag "${LOCAL_IMAGE}" "${GHCR_IMAGE_1}"
docker tag "${LOCAL_IMAGE}" "${GHCR_IMAGE_2}"

# Push to GHCR
echo "Pushing ${GHCR_IMAGE_1}..."
if docker push "${GHCR_IMAGE_1}"; then
	echo "✅ Successfully pushed ${GHCR_IMAGE_1}"
else
	echo "❌ Failed to push ${GHCR_IMAGE_1}"
	exit 1
fi

echo "Pushing ${GHCR_IMAGE_2}..."
if docker push "${GHCR_IMAGE_2}"; then
	echo "✅ Successfully pushed ${GHCR_IMAGE_2}"
else
	echo "❌ Failed to push ${GHCR_IMAGE_2}"
	exit 1
fi

echo ""
echo "🎉 Successfully published Docker images to GitHub Container Registry!"
echo ""
echo "Images available at:"
echo "  - ${GHCR_IMAGE_1}"
echo "  - ${GHCR_IMAGE_2}"
echo ""
echo "To run from GHCR:"
echo "  docker run -p 3000:3000 -p 3001:3001 ${GHCR_IMAGE_1}"
echo ""
echo "To update run-docker.sh to use GHCR:"
echo "  ./run-docker.sh container-name ${TAG} --from-ghcr"